<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Ews_model extends CI_Model {

	var $table = 'tb_ews';
	var $column_order = array('perkara_id', 'nama_pa', 'nomor_perkara','tanggal_pendaftaran',null); //set column field database for datatable orderable
	var $column_search = array('perkara_id', 'nama_pa', 'nomor_perkara','tanggal_pendaftaran'); //set column field database for datatable searchable just firstname , lastname , address are searchable
	var $order = array('perkara_id' => 'desc'); // default order 

	public function __construct()
	{
		parent::__construct();
		$this->load->database();
	}

	private function _get_datatables_query()
	{
		
		$this->db->from($this->table);

		$i = 0;
	
		foreach ($this->column_search as $item) // loop column 
		{
			if($_POST['search']['value']) // if datatable send POST for search
			{
				
				if($i===0) // first loop
				{
					$this->db->group_start(); // open bracket. query Where with OR clause better with bracket. because maybe can combine with other WHERE with AND.
					$this->db->like($item, $_POST['search']['value']);
				}
				else
				{
					$this->db->or_like($item, $_POST['search']['value']);
				}

				if(count($this->column_search) - 1 == $i) //last loop
					$this->db->group_end(); //close bracket
			}
			$i++;
		}
		
		if(isset($_POST['order'])) // here order processing
		{
			$this->db->order_by($this->column_order[$_POST['order']['0']['column']], $_POST['order']['0']['dir']);
		} 
		else if(isset($this->order))
		{
			$order = $this->order;
			$this->db->order_by(key($order), $order[key($order)]);
		}
	}

	function get_datatables()
	{
		$this->_get_datatables_query();
		if($_POST['length'] != -1)
		$this->db->limit($_POST['length'], $_POST['start']);
		$query = $this->db->get();
		return $query->result();
	}

	function get_datatablesHT($nmHT)
	{
		$this->db->from($this->table);
		$this->db->join('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('ip_public.hakim_tinggi_pengawas',$nmHT);

		$i = 0;
	
		foreach ($this->column_search as $item) // loop column 
		{
			if($_POST['search']['value']) // if datatable send POST for search
			{
				
				if($i===0) // first loop
				{
					$this->db->group_start(); // open bracket. query Where with OR clause better with bracket. because maybe can combine with other WHERE with AND.
					$this->db->like($item, $_POST['search']['value']);
				}
				else
				{
					$this->db->or_like($item, $_POST['search']['value']);
				}

				if(count($this->column_search) - 1 == $i) //last loop
					$this->db->group_end(); //close bracket
			}
			$i++;
		}	
		if(isset($_POST['order'])) // here order processing
		{
			$this->db->order_by($this->column_order[$_POST['order']['0']['column']], $_POST['order']['0']['dir']);
		} 
		else if(isset($this->order))
		{
			$order = $this->order;
			$this->db->order_by(key($order), $order[key($order)]);
		}			
		if($_POST['length'] != -1)
		$this->db->limit($_POST['length'], $_POST['start']);
		$query = $this->db->get();
		return $query->result();
	}

	function count_filtered()
	{
		$this->_get_datatables_query();
		$query = $this->db->get();
		return $query->num_rows();
	}

	public function count_all()
	{
		$this->db->from($this->table);
		return $this->db->count_all_results();
	}

	function count_filteredHT($nmHT)
	{
		$nama = $nmHT;
		$this->db->from($this->table);
		$this->db->join('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('ip_public.hakim_tinggi_pengawas',$nmHT);
		$query = $this->db->get();
		return $query->num_rows();
	}

	public function count_allHT($nmHT)
	{
		$nama = $nmHT;
		$this->db->from($this->table);
		$this->db->join('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('ip_public.hakim_tinggi_pengawas',$nmHT);
		return $this->db->count_all_results();
	}

	public function get_by_id($id)
	{
		$this->db->select('*', 'ip_public.hakim_tinggi_pengawas');
		$this->db->from($this->table);
		$this->db->JOIN('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('perkara_id',$id);
		$query = $this->db->get();

		return $query->row();
	}

	public function getDataEWS($namapa)
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('nama_pa',$namapa);
		$query = $this->db->get();
		return $query->result();
	}

	public function getIndikator($id)
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('perkara_id',$id);
		$query = $this->db->get();
		return $query->result();
	}

	public function getTtlEss()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$query = $this->db->get();
		return $query->num_rows();	
	}
	public function getTtlEssHT($nmHT)
	{
		$nama = $nmHT;
		$this->db->from($this->table);
		$this->db->join('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('ip_public.hakim_tinggi_pengawas',$nmHT);
		$query = $this->db->get();
		return $query->num_rows();
	}
	public function getTtlDiawasi()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('statusess',1);
		$query = $this->db->get();
		return $query->num_rows();	
	}
	public function getTtlDiawasiHT($nmHT)
	{
		$nama = $nmHT;
		$this->db->from($this->table);
		$this->db->join('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('ip_public.hakim_tinggi_pengawas',$nmHT);
		$this->db->WHERE('statusess',1);
		$query = $this->db->get();
		return $query->num_rows();
	}
	public function getTtlBlmDiawasi()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('statusess =',0);
		$query = $this->db->get();
		return $query->num_rows();	
	}
	public function getTtlBlmDiawasiHT($nmHT)
	{
		$nama = $nmHT;
		$this->db->from($this->table);
		$this->db->join('ip_public','tb_ews.id_satker=ip_public.id');
		$this->db->where('ip_public.hakim_tinggi_pengawas',$nmHT);
		$this->db->WHERE('statusess',0);
		$query = $this->db->get();
		return $query->num_rows();	
	}
	public function getDataBlmDiawasi()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('statusess =',0);
		$query = $this->db->get();
		return $query->result();	
	}

	public function totalEWS()
	{
		$this->db->select('perkara_id');
		$this->db->from($this->table);
		$this->db->WHERE('statusess',0);
		$query = $this->db->get();
		return $query->num_rows();
	}

	public function ttlHB()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('jenis_perkara_nama','Harta bersama');
		$query = $this->db->get();
		return $query->num_rows();		
	}

	public function ttlWaris()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('jenis_perkara_nama','Kewarisan');
		$query = $this->db->get();
		return $query->num_rows();		
	}

	public function ttlCG()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$this->db->WHERE('jenis_perkara_nama','Cerai Gugat');
		$query = $this->db->get();
		return $query->num_rows();		
	}

	public function ttlLain()
	{
		$this->db->select('*');
		$this->db->from($this->table);
		$perkNama = array('Cerai Gugat', 'Harta Bersama', 'Kewarisan');
		$this->db->WHERE_not_in('jenis_perkara_nama', $perkNama);
		$query = $this->db->get();
		return $query->num_rows();		
	}	

	public function save($data)
	{
		$this->db->insert($this->table, $data);
		return $this->db->insert_id();
	}

	public function update($where, $data)
	{
		$this->db->update($this->table, $data, $where);
		return $this->db->affected_rows();
	}

	public function delete_by_id($id)
	{
		$this->db->where('perkara_id', $id);
		$this->db->delete($this->table);
	}

	public function untukChart()
	{
		$this->db->select('COUNT("jenis_perkara_nama") AS jml, nama_pa');
		$this->db->from($this->table);
		$this->db->group_by ('nama_pa');
		$query = $this->db->get();
		return $query->result_array();		
	}

	public function satkerChart()
	{
		$this->db->select('nama_pa');
		$this->db->from($this->table);
		$this->db->group_by ('nama_pa');
		$query = $this->db->get();
		return $query->result_array();		
	}	

	public function untukChartPerk()
	{
		$this->db->select('jenis_perkara_nama, COUNT("jenis_perkara_nama") AS jml');
		$this->db->from($this->table);
		$this->db->group_by ('jenis_perkara_nama');
		$query = $this->db->get();
		return $query->result_array();		
	}	
}